.. _pecan_rest:

:mod:`pecan.rest` -- Pecan ``REST`` Controller
==============================================

The :mod:`pecan.rest` module includes support for writing fully
``RESTful`` controllers in your Pecan application.

.. automodule:: pecan.rest
  :members:
  :show-inheritance: